<?php
/**
 * @copyright Copyright (C) 2010-2022, the Friendica project
 *
 * @license GNU AGPL version 3 or any later version
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as
 * published by the Free Software Foundation, either version 3 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License
 * along with this program.  If not, see <https://www.gnu.org/licenses/>.
 *
 */

namespace Friendica\Test\src\Database;

use Dice\Dice;
use Friendica\Database\Database;
use Friendica\Database\DBA;
use Friendica\DI;
use Friendica\Test\DatabaseTest;
use Friendica\Test\Util\Database\StaticDatabase;

class DBATest extends DatabaseTest
{
	protected function setUp(): void
	{
		parent::setUp();

		$dice = (new Dice())
			->addRules(include __DIR__ . '/../../../static/dependencies.config.php')
			->addRule(Database::class, ['instanceOf' => StaticDatabase::class, 'shared' => true]);
		DI::init($dice);

		// Default config
		DI::config()->set('config', 'hostname', 'localhost');
		DI::config()->set('system', 'throttle_limit_day', 100);
		DI::config()->set('system', 'throttle_limit_week', 100);
		DI::config()->set('system', 'throttle_limit_month', 100);
		DI::config()->set('system', 'theme', 'system_theme');
	}

	/**
	 * @small
	 */
	public function testExists() {

		self::assertTrue(DBA::exists('config', []));
		self::assertFalse(DBA::exists('notable', []));

		self::assertTrue(DBA::exists('config', null));
		self::assertFalse(DBA::exists('notable', null));

		self::assertTrue(DBA::exists('config', ['k' => 'hostname']));
		self::assertFalse(DBA::exists('config', ['k' => 'nonsense']));
	}
}
